@@ -67,7 +67,7 @@ class RssBot:
             if not existd:
                 _p = {"group_id": group_id, "pubkey": pubkey, "name": _name, "wallet": _wallet, "timestamp": ts}
                 self.db.add(BotRumProfiles(_p))
-            elif existd.timestap < ts:
+            elif existd.timestamp < ts:
                 _p = {"timestamp": ts}
                 if _name != existd.name:
                     _p["name"] = _name
@@ -90,6 +90,7 @@ class RssBot:
             _gid = commands[k]["group_id"]
             if _gid not in (None, -1):
                 self.rum.group_id = _gid
+
                 existd = self.db.session.query(BotRumGroups).filter(BotRumGroups.group_id == _gid).first()
                 _m = commands[k].get("minutes") or -30
                 if existd is None:
