@@ -3,5 +3,8 @@ from bot import bot
 
 while True:
     print(datetime.datetime.now(), "new round", "+" * 40)
-    bot.do_rss()
+    try:
+        bot.do_rss()
+    except Exception as e:
+        print(e)
     time.sleep(10)
