@@ -9,8 +9,6 @@ requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
 
 from rumpy.client import api
 from rumpy.client.api.base import BaseAPI
-from rumpy.client.module import *
-from rumpy.client.module_op import BaseDB
 from rumpy.client.config import PORT, CRTFILE
 
 logger = logging.getLogger(__name__)
@@ -26,7 +24,6 @@ class RumClient:
     node = api.Node()
     config = api.GroupConfig()
     paid = api.PaidGroup()
-    db = None
 
     def __new__(cls, *args, **kwargs):
         self = super().__new__(cls)
@@ -44,10 +41,6 @@ class RumClient:
         host: str = "127.0.0.1",
         appid: str = "peer",
         jwt_token: str = None,
-        usedb: bool = False,
-        dbname: str = "test_db",
-        dbecho: bool = False,
-        dbreset: bool = False,
     ):
         """
         :param appid, str, Rum 客户端标识，自定义，随便写
@@ -63,10 +56,6 @@ class RumClient:
             "appid": appid,
             "crtfile": crtfile,
             "jwt_token": jwt_token,
-            "usedb": usedb,
-            "dbname": dbname,
-            "dbecho": dbecho,
-            "dbreset": dbreset,
         }
         requests.adapters.DEFAULT_RETRIES = 5
 
@@ -86,14 +75,6 @@ class RumClient:
         self.baseurl_app = f"https://{host}:{port}/app/api/v1"
         os.environ["NO_PROXY"] = ",".join([os.getenv("NO_PROXY", ""), self.baseurl, self.baseurl_app])
 
-        self.usedb = usedb
-        if self.usedb:
-            self.db = BaseDB(
-                dbname,
-                echo=dbecho,
-                reset=dbreset,
-            )
-
     def _request(self, method: str, url: str, relay: Dict = {}):
 
         try:
@@ -107,19 +88,7 @@ class RumClient:
         return self._request("get", url, relay)
 
     def post(self, url: str, relay: Dict = {}):
-        if self.usedb:
-            resp = self._request("post", url, relay)
-            if "trx_id" in resp:
-                action = {
-                    "group_id": self.group_id,
-                    "trx_id": resp["trx_id"],
-                    "func": "post",
-                    "params": {"url": url, "relay": relay},
-                }
-                self.db.save(Action(action))
-            return resp
-        else:
-            return self._request("post", url, relay)
+        return self._request("post", url, relay)
 
     @property
     def group_id(self):
